@@ -3,7 +3,10 @@
 
 package arm
 
-import "github.com/Azure/go-autorest/autorest/azure"
+import (
+	"github.com/Azure/go-autorest/autorest/adal"
+	"github.com/Azure/go-autorest/autorest/azure"
+)
 
 type Authenticate struct {
 	env          azure.Environment
@@ -21,17 +24,17 @@ func NewAuthenticate(env azure.Environment, clientID, clientSecret, tenantID str
 	}
 }
 
-func (a *Authenticate) getServicePrincipalToken() (*azure.ServicePrincipalToken, error) {
+func (a *Authenticate) getServicePrincipalToken() (*adal.ServicePrincipalToken, error) {
 	return a.getServicePrincipalTokenWithResource(a.env.ResourceManagerEndpoint)
 }
 
-func (a *Authenticate) getServicePrincipalTokenWithResource(resource string) (*azure.ServicePrincipalToken, error) {
-	oauthConfig, err := a.env.OAuthConfigForTenant(a.tenantID)
+func (a *Authenticate) getServicePrincipalTokenWithResource(resource string) (*adal.ServicePrincipalToken, error) {
+	oauthConfig, err := adal.NewOAuthConfig(a.env.ActiveDirectoryEndpoint, a.tenantID)
 	if err != nil {
 		return nil, err
 	}
 
-	spt, err := azure.NewServicePrincipalToken(
+	spt, err := adal.NewServicePrincipalToken(
 		*oauthConfig,
 		a.clientID,
 		a.clientSecret,
